# eric7.WebBrowser.PageScreenDialog

Module implementing a dialog to save a screenshot of a web page.

### Global Attributes

None

### Classes

PageScreenDialog | Class implementing a dialog to save a screenshot of a web page.

### Functions

None

## PageScreenDialog

Class implementing a dialog to save a screenshot of a web page.

### Derived from

QDialog, Ui_PageScreenDialog

### Class Attributes

None

### Class Methods

None

### Methods

PageScreenDialog | Constructor
__createPixmap | Private slot to create a pixmap of the associated view's page.
__savePageScreen | Private slot to save the page screen.
on_buttonBox_clicked | Private slot to handle clicks of the dialog buttons.

### Static Methods

None

#### PageScreenDialog (Constructor)

PageScreenDialog(view, parent=None)

Constructor

view
  reference to the web view containing the page to be saved (WebBrowserView)
parent
  reference to the parent widget (QWidget)

#### PageScreenDialog.__createPixmap

__createPixmap()

Private slot to create a pixmap of the associated view's page.

#### PageScreenDialog.__savePageScreen

__savePageScreen()

Private slot to save the page screen.

Return:
  flag indicating success (boolean)

#### PageScreenDialog.on_buttonBox_clicked

on_buttonBox_clicked(button)

Private slot to handle clicks of the dialog buttons.

button
  button that was clicked (QAbstractButton)

Up